       IDENTIFICATION DIVISION.
       PROGRAM-ID.    NBRTYPC1.
       AUTHOR.        SIMOTIME TECHNOLOGIES.
      *****************************************************************
      * Copyright (C) 1987-2019 SimoTime Technologies.                *
      *                                                               *
      * All rights reserved.  Unpublished, all rights reserved under  *
      * copyright law and international treaty.  Use of a copyright   *
      * notice is precautionary only and does not imply publication   *
      * or disclosure.                                                *
      *                                                               *
      * Permission to use, copy, modify and distribute this software  *
      * for any non-commercial purpose and without fee is hereby      *
      * granted, provided the SimoTime copyright notice appear on all *
      * copies of the software. The SimoTime name or Logo may not be  *
      * used in any advertising or publicity pertaining to the use    *
      * of the software without the written permission of SimoTime    *
      * Technologies.                                                 *
      *                                                               *
      * Permission to use, copy, modify and distribute this software  *
      * for any commercial purpose requires a fee to be paid to       *
      * SimoTime Technologies. Once the fee is received by SimoTime   *
      * the latest version of the software will be delivered and a    *
      * license will be granted for use within an enterprise,         *
      * provided the SimoTime copyright notice appear on all copies   *
      * of the software. The SimoTime name or Logo may not be used    *
      * in any advertising or publicity pertaining to the use of the  *
      * software without the written permission of SimoTime           *
      * Technologies.                                                 *
      *                                                               *
      * SimoTime Technologies makes no warranty or representations    *
      * about the suitability of the software for any purpose. It is  *
      * provided "AS IS" without any expressed or implied warranty,   *
      * including the implied warranties of merchantability, fitness  *
      * for a particular purpose and non-infringement. SimoTime       *
      * Technologies shall not be liable for any direct, indirect,    *
      * special or consequential damages resulting from the loss of   *
      * use, data or projects, whether in an action of contract or    *
      * tort, arising out of or in connection with the use or         *
      * performance of this software                                  *
      *                                                               *
      * SimoTime Technologies                                         *
      * 15 Carnoustie Drive                                           *
      * Novato, CA 94949-5849                                         *
      * 415.883.6565                                                  *
      *                                                               *
      * RESTRICTED RIGHTS LEGEND                                      *
      * Use, duplication, or disclosure by the Government is subject  *
      * to restrictions as set forth in subparagraph (c)(1)(ii) of    *
      * the Rights in Technical Data and Computer Software clause at  *
      * DFARS 52.227-7013 or subparagraphs (c)(1) and (2) of          *
      * Commercial  Computer Software - Restricted Rights  at 48      *
      * CFR 52.227-19, as applicable.  Contact SimoTime Technologies, *
      * 15 Carnoustie Drive, Novato, CA 94949-5849.                   *
      *                                                               *
      *****************************************************************
      *      This program is provided by SimoTime Technologies        *
      *        Our e-mail address is: helpdesk@simotime.com           *
      *     Also, visit our Web Site at http://www.simotime.com       *
      *                                                               *
      *****************************************************************
      *
      *****************************************************************
      * Source Member: NBRTYPC1.CBL
      *****************************************************************
      *
      * NBRTYPC1 - Numeric formats for COBOL.
      *
      *
      * DESCRIPTION
      * -----------
      * This set of programs is used to show the various numeric
      * format used by the COBOL Program Language.
      *
      * This program illustrates the use of some of the commonly
      * used numeric formats. It will show actual hex-dump content of
      * the fields along with the field length for the display format
      * (actual digits), the packed format (COMP-3) and the binary
      * (COMP)
      * formats.
      *
      * The COBOL programs are compiled with the ASSIGN(EXTERNAL)
      * directive. This provides for external file mapping of file
      * names.
      *
      * When running with Net Express the IBMCOMP an NOTRUNC directives
      * will be required to maintain compatability with the mainframe
      * format and field sizes for binary fields.
      *
      * This technique provides for the use of a single COBOL source
      * program that will run on OS/390, Windows or Unix.
      *
      * This program will run on a Personal Computer with Windows
      * and Micro Focus Net Express or Mainframe Express.
      *
      * This program will also run on an IBM Mainframe.
      *
      *****************************************************************
      *
      * MAINTENANCE
      * -----------
      * 1996/03/15 Simmons, Created program.
      * 1996/03/15 Simmons, No changes to date.
      *
      *****************************************************************
      *
       ENVIRONMENT DIVISION.
       DATA DIVISION.
       WORKING-STORAGE SECTION.
      *****************************************************************
      *    Data-structure for Title and Copyright...
      *    ------------------------------------------------------------
       01  SIM-TITLE.
           05  T1 pic X(11) value '* NBRTYPC1 '.
           05  T2 pic X(34) value 'Numeric Field Formats for COBOL   '.
           05  T3 pic X(10) value ' v11.12.19'.
           05  T4 pic X(24) value ' http://www.simotime.com'.
       01  SIM-COPYRIGHT.
           05  C1 pic X(11) value '* NBRTYPC1 '.
           05  C2 pic X(20) value 'Copyright 1987-2019 '.
           05  C3 pic X(28) value '   SimoTime Technologies    '.
           05  C4 pic X(20) value ' All Rights Reserved'.

       01  SIM-THANKS-01.
           05  C1 pic X(11) value '* NBRTYPC1 '.
           05  C2 pic X(32) value 'Thank you for using this program'.
           05  C3 pic X(32) value ' provided from SimoTime Technolo'.
           05  C4 pic X(04) value 'gies'.

       01  SIM-THANKS-02.
           05  C1 pic X(11) value '* NBRTYPC1 '.
           05  C2 pic X(32) value 'Please send all inquires or sugg'.
           05  C3 pic X(32) value 'estions to the helpdesk@simotime'.
           05  C4 pic X(04) value '.com'.

      *****************************************************************
      *    Buffer used for posting messages to the console.
      *    ------------------------------------------------------------
       01  MESSAGE-BUFFER.
           05  MESSAGE-HEADER      pic X(11)   value '* NBRTYPC1 '.
           05  MESSAGE-TEXT        pic X(68).

      *****************************************************************
      *    Coding techniques for various numeric formats...
      *    ------------------------------------------------------------
      *    The following shows the full syntax for ZONED-DECIMAL
       01  ZONE-DECIMAL-UNSIGN     pic 9(5)  USAGE IS DISPLAY.
      *    However, it is usually coded as follows.
       01  ZONE-DECIMAL-UNSIGN-2   PIC 9(5).
      *    For Working Storage fields a value clause may be added to
      *    minimize or avoid the occurence of a "S0C7" or an error
      *    message of "Invalid value in numeric field" followed
      *    by a program ABEND. The value clause will cause the field
      *    to contain all ZEROES when the program is loaded. If the
      *    value clause is not used as follows the numeric field may
      *    contain spaces.
       01  ZONE-DECIMAL-UNSIGN-2   PIC 9(5) VALUE 0.

      *    ------------------------------------------------------------
      *    The following is the full syntax for PACKED-DECIMAL.
       01  PACK-DECIMAL-UNSIGN     pic 9(5)  USAGE IS COMPUTATIONAL-3.
      *    However, it is usually coded as follows. The VALUE clause
      *    is optional and will initialize the field to ZEROES when
      *    the program is started.
       01  PACK-DECIMAL-UNSIGN-2   pic 9(5)  COMP-3 VALUE 0.

      *    ------------------------------------------------------------
      *    The following is the full syntax for BINARY or COMP field.
       01  BINARY-UNSIGN           pic 9(5)  USAGE IS COMPUTATIONAL.
      *
      *    However, it is usually coded as follows. The VALUE clause
      *    is optional and will initialize the field to ZEROES when
      *    the program is started.
       01  BINARY-UNSIGN-2         pic 9(5)  COMP VALUE 0.

      *****************************************************************
      *    Various numeric formats used by COBOL...
      *    ------------------------------------------------------------
       01  UNSIGNED-123            pic 9(5)            value 123.
       01  UNSIGNED-123-X          REDEFINES   UNSIGNED-123
                                   pic X(5).

       01  PLUS-123                pic S9(5)           value +123.
       01  PLUS-123-X              REDEFINES   PLUS-123
                                   pic X(5).
       01  PLUS-123-PACKED         pic S9(5)   COMP-3  value +123.
       01  PLUS-123-PACKED-X       REDEFINES   PLUS-123-PACKED
                                   pic X(3).
       01  PLUS-123-BINARY         pic S9(5)   BINARY  value +123.
       01  PLUS-123-BINARY-X       REDEFINES   PLUS-123-BINARY
                                   pic X(4).

       01  PLUS-123-SL             pic S9(5)           value +123
                                   SIGN LEADING.
       01  PLUS-123-SL-X           REDEFINES   PLUS-123-SL
                                   pic X(5).
       01  PLUS-123-ST             pic S9(5)           value +123
                                   SIGN TRAILING.
       01  PLUS-123-ST-X           REDEFINES   PLUS-123-ST
                                   pic X(5).

       01  PLUS-123-SLS            pic S9(5)           value +123
                                   SIGN LEADING SEPARATE.
       01  PLUS-123-SLS-X          REDEFINES   PLUS-123-SLS
                                   pic X(6).
       01  PLUS-123-STS            pic S9(5)           value +123
                                   SIGN TRAILING SEPARATE.
       01  PLUS-123-STS-X          REDEFINES   PLUS-123-STS
                                   pic X(6).

       01  MINUS-123               pic S9(5)           value -123.
       01  MINUS-123-X             REDEFINES   MINUS-123
                                   pic X(5).
       01  MINUS-123-PACKED        pic S9(5)   COMP-3  value -123.
       01  MINUS-123-PACKED-X      REDEFINES   MINUS-123-PACKED
                                   pic X(3).
       01  MINUS-123-BINARY        pic S9(5)   BINARY  value -123.
       01  MINUS-123-BINARY-X      REDEFINES   MINUS-123-BINARY
                                   pic X(4).

       01  MINUS-123-SL            pic S9(5)           value -123
                                   SIGN LEADING.
       01  MINUS-123-SL-X          REDEFINES   MINUS-123-SL
                                   pic X(5).
       01  MINUS-123-ST            pic S9(5)           value -123
                                   SIGN TRAILING.
       01  MINUS-123-ST-X          REDEFINES   MINUS-123-ST
                                   pic X(5).

       01  MINUS-123-SLS           pic S9(5)           value -123
                                   SIGN LEADING SEPARATE.
       01  MINUS-123-SLS-X         REDEFINES   MINUS-123-SLS
                                   pic X(6).
       01  MINUS-123-STS           pic S9(5)           value -123
                                   SIGN TRAILING SEPARATE.
       01  MINUS-123-STS-X         REDEFINES   MINUS-123-STS
                                   pic X(6).

       01  FIELD-LENGTH            pic 9(3)    value 0.
       01  FIELD-LENGTH-X          REDEFINES   FIELD-LENGTH
                                   pic X(3).
       01  LENGTH-OF-FIELDS.
           05  FILLER              pic X(7)    value 'Digits='.
           05  DIGITS-LENGTH       pic 9(3)    value 0.
           05  FILLER              pic X(8)    value ' Packed='.
           05  PACKED-LENGTH       pic 9(3)    value 0.
           05  FILLER              pic X(8)    value ' Binary='.
           05  BINARY-LENGTH       pic 9(3)    value 0.
           05  FILLER              pic X       value SPACE.
           05  FILLER              pic X       value SPACE.
           05  FIELD-NAME          pic X(32).
           05  FILLER              pic X(2)    value SPACES.

       01  NBR-01-DIGITS pic 9            value 1.
       01  NBR-01-PACKED pic 9     COMP-3 value 1.
       01  NBR-01-BINARY pic 9     COMP   value 1.

       01  NBR-02-DIGITS pic 9(02)        value 12.
       01  NBR-02-PACKED pic 9(02) COMP-3 value 12.
       01  NBR-02-BINARY pic 9(02) COMP   value 12.

       01  NBR-03-DIGITS pic 9(03)        value 123.
       01  NBR-03-PACKED pic 9(03) COMP-3 value 123.
       01  NBR-03-BINARY pic 9(03) COMP   value 123.

       01  NBR-04-DIGITS pic 9(04)        value 1234.
       01  NBR-04-PACKED pic 9(04) COMP-3 value 1234.
       01  NBR-04-BINARY pic 9(04) COMP   value 1234.

       01  NBR-05-DIGITS pic 9(05)        value 12345.
       01  NBR-05-PACKED pic 9(05) COMP-3 value 12345.
       01  NBR-05-BINARY pic 9(05) COMP   value 12345.

       01  NBR-06-DIGITS pic 9(06)        value 123456.
       01  NBR-06-PACKED pic 9(06) COMP-3 value 123456.
       01  NBR-06-BINARY pic 9(06) COMP   value 123456.

       01  NBR-07-DIGITS pic 9(07)        value 1234567.
       01  NBR-07-PACKED pic 9(07) COMP-3 value 1234567.
       01  NBR-07-BINARY pic 9(07) COMP   value 1234567.

       01  NBR-08-DIGITS pic 9(08)        value 12345678.
       01  NBR-08-PACKED pic 9(08) COMP-3 value 12345678.
       01  NBR-08-BINARY pic 9(08) COMP   value 12345678.

       01  NBR-09-DIGITS pic 9(09)        value 123456789.
       01  NBR-09-PACKED pic 9(09) COMP-3 value 123456789.
       01  NBR-09-BINARY pic 9(09) COMP   value 123456789.

       01  NBR-10-DIGITS pic 9(10)        value 1234567890.
       01  NBR-10-PACKED pic 9(10) COMP-3 value 1234567890.
       01  NBR-10-BINARY pic 9(10) COMP   value 1234567890.

       01  NBR-11-DIGITS pic 9(11)        value 12345678901.
       01  NBR-11-PACKED pic 9(11) COMP-3 value 12345678901.
       01  NBR-11-BINARY pic 9(11) COMP   value 12345678901.

       01  NBR-12-DIGITS pic 9(12)        value 123456789012.
       01  NBR-12-PACKED pic 9(12) COMP-3 value 123456789012.
       01  NBR-12-BINARY pic 9(12) COMP   value 123456789012.

       01  NBR-13-DIGITS pic 9(13)        value 1234567890123.
       01  NBR-13-PACKED pic 9(13) COMP-3 value 1234567890123.
       01  NBR-13-BINARY pic 9(13) COMP   value 1234567890123.

       01  NBR-14-DIGITS pic 9(14)        value 12345678901234.
       01  NBR-14-PACKED pic 9(14) COMP-3 value 12345678901234.
       01  NBR-14-BINARY pic 9(14) COMP   value 12345678901234.

       01  NBR-15-DIGITS pic 9(15)        value 123456789012345.
       01  NBR-15-PACKED pic 9(15) COMP-3 value 123456789012345.
       01  NBR-15-BINARY pic 9(15) COMP   value 123456789012345.

       01  NBR-16-DIGITS pic 9(16)        value 1234567890123456.
       01  NBR-16-PACKED pic 9(16) COMP-3 value 1234567890123456.
       01  NBR-16-BINARY pic 9(16) COMP   value 1234567890123456.

       01  NBR-17-DIGITS pic 9(17)        value 12345678901234567.
       01  NBR-17-PACKED pic 9(17) COMP-3 value 12345678901234567.
       01  NBR-17-BINARY pic 9(17) COMP   value 12345678901234567.

       01  NBR-18-DIGITS pic 9(18)        value 123456789012345678.
       01  NBR-18-PACKED pic 9(18) COMP-3 value 123456789012345678.
       01  NBR-18-BINARY pic 9(18) COMP   value 123456789012345678.

       COPY PASSDUMP.

      *****************************************************************
       PROCEDURE DIVISION.
           perform FIRST-TIME-LOGIC

      *    ------------------------------------------------------------
      *    Example-01, Show the Hex format for a SIMPLE, UNSIGNED
      *    NUMERIC field...
           perform EXAMPLE-01

      *    ------------------------------------------------------------
      *    Example-02, Show the Hex format for a SIMPLE, SIGNED
      *    NUMERIC field...
           perform EXAMPLE-02

      *    ------------------------------------------------------------
      *    Example-03, Show the Hex format for a SIGNED, PACKED,
      *    NUMERIC field...
           perform EXAMPLE-03

      *    ------------------------------------------------------------
      *    Example-04, Show the Hex format for a SIGNED, BINARY,
      *    NUMERIC field...
           perform EXAMPLE-04

      *    ------------------------------------------------------------
      *    Example-05, Show the Hex format for a SIGN, LEADING,
      *    NUMERIC field...
           perform EXAMPLE-05

      *    ------------------------------------------------------------
      *    Example-06, Show the Hex format for a SIGN, TRAILING,
      *    NUMERIC field...
           perform EXAMPLE-06

      *    ------------------------------------------------------------
      *    Example-07, Show the Hex format for a SIGN, LEADING,
      *    SEPARATE, NUMERIC field...
           perform EXAMPLE-07

      *    ------------------------------------------------------------
      *    Example-08, Show the Hex format for a SIGN, TRAILING,
      *    SEPARATE, NUMERIC field...
           perform EXAMPLE-08

      *    ------------------------------------------------------------
      *    Example-09, Show the Specfied size and actual field length.
           perform EXAMPLE-09

           GOBACK.

      *****************************************************************
       DUMP-ASTERISK-ROW.
           move 'NOTE' to SIMODUMP-REQUEST
           move all '*' to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
           exit.

      *****************************************************************
       DUMP-ASTERISK-ROW-2X.
           perform DUMP-ASTERISK-SINGLE
           perform DUMP-ASTERISK-ROW
           exit.

      *****************************************************************
       DUMP-ASTERISK-SINGLE.
           move 'NOTE' to SIMODUMP-REQUEST
           move SPACES to SIMODUMP-BUFFER
           move '*'    to SIMODUMP-BUFFER(1:1)
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
           exit.

      *****************************************************************
      * Show the Hex format for a SIMPLE, UNSIGNED, NUMERIC field...
      *****************************************************************
       EXAMPLE-01.
      *    Prepare to show the Number...
           move 'Task0001' to SIMODUMP-DUMP-ID
           perform DUMP-ASTERISK-ROW-2X
           move 'UNSIGNED-123 PIC 9(5)' to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Show the hexadecimal content of the field...
           move 'DUMP'         to SIMODUMP-REQUEST
           add length of UNSIGNED-123 to ZERO giving SIMODUMP-LENGTH
           move SPACES         to SIMODUMP-BUFFER
           move UNSIGNED-123-X to SIMODUMP-BUFFER
           call 'SIMODUMP'  using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
           exit.

      *****************************************************************
      * Show the Hex format for a SIGNED, NUMERIC field...
      *****************************************************************
       EXAMPLE-02.
      *    Prepare to show the Positive Number...
           move 'Task0002'    to SIMODUMP-DUMP-ID
           perform DUMP-ASTERISK-ROW-2X
           move 'PLUS-123 PIC S9(5)' to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Show the hexadecimal content of the Positive Number...
           move 'DUMP'        to SIMODUMP-REQUEST
           add  length of PLUS-123 to ZERO giving SIMODUMP-LENGTH
           move SPACES        to SIMODUMP-BUFFER
           move PLUS-123-X    to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Prepare to show the Negative Number...
           perform DUMP-ASTERISK-SINGLE
           move 'MINUS-123 PIC S9(5)' to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Show the hexadecimal content of the Negative Number...
           move 'DUMP'        to SIMODUMP-REQUEST
           add  length of MINUS-123 to ZERO giving SIMODUMP-LENGTH
           move SPACES        to SIMODUMP-BUFFER
           move MINUS-123-X   to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
           exit.

      *****************************************************************
      * Show the Hex format for a SIGNED, PACKED, NUMERIC field...
      *****************************************************************
       EXAMPLE-03.
      *    Prepare to show the Positive Number...
           move 'Task0003'    to SIMODUMP-DUMP-ID
           perform DUMP-ASTERISK-ROW-2X
           move 'PLUS-123-PACKED PIC S9(5) COMP-3' to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Show the hexadecimal content of the Positive Number...
           move 'DUMP'        to SIMODUMP-REQUEST
           add  length of PLUS-123-PACKED to ZERO
                giving SIMODUMP-LENGTH
           move SPACES        to SIMODUMP-BUFFER
           move PLUS-123-PACKED-X to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Prepare to show the Negative Number...
           perform DUMP-ASTERISK-SINGLE
           move 'MINUS-123-PACKED PIC S9(5) COMP-3' to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Show the hexadecimal content of the Negative Number...
           move 'DUMP'             to SIMODUMP-REQUEST
           add  length of MINUS-123-PACKED to ZERO
                giving SIMODUMP-LENGTH
           move SPACES             to SIMODUMP-BUFFER
           move MINUS-123-PACKED-X to SIMODUMP-BUFFER
           call 'SIMODUMP'      using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
           exit.

      *****************************************************************
      * Show the Hex format for a SIGNED, BINARY, NUMERIC field...
      *****************************************************************
       EXAMPLE-04.
      *    Prepare to show the Positive Number...
           move 'Task0004' to SIMODUMP-DUMP-ID
           perform DUMP-ASTERISK-ROW-2X
           move 'PLUS-123-BINARY PIC S9(5) BINARY' to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Show the hexadecimal content of the Positive Number...
           move 'DUMP' to SIMODUMP-REQUEST
           add  length of PLUS-123-BINARY to ZERO
                giving SIMODUMP-LENGTH
           move SPACES to SIMODUMP-BUFFER
           move PLUS-123-BINARY-X to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Prepare to show the Negative Number...
           perform DUMP-ASTERISK-SINGLE
           move 'MINUS-123-BINARY PIC S9(5) BINARY' to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Show the hexadecimal content of the Negative Number...
           move 'DUMP' to SIMODUMP-REQUEST
           add  length of MINUS-123-BINARY to ZERO
                giving SIMODUMP-LENGTH
           move SPACES to SIMODUMP-BUFFER
           move MINUS-123-BINARY-X to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
           exit.

      *****************************************************************
      * Show the Hex format for a SIGN, LEADING, NUMERIC field...
      *****************************************************************
       EXAMPLE-05.
      *    Prepare to show the Positive Number...
           move 'Task0005' to SIMODUMP-DUMP-ID
           perform DUMP-ASTERISK-ROW-2X
           move 'PLUS-123-SL PIC S9(5) SIGN LEADING' to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Show the hexadecimal content of the Positive Number...
           move 'DUMP' to SIMODUMP-REQUEST
           add  length of PLUS-123-SL to ZERO giving SIMODUMP-LENGTH
           move SPACES to SIMODUMP-BUFFER
           move PLUS-123-SL-X to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Prepare to show the Negative Number...
           perform DUMP-ASTERISK-SINGLE
           move 'MINUS-123-SL PIC S9(5) SIGN LEADING'
             to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Show the hexadecimal content of the Negative Number...
           move 'DUMP' to SIMODUMP-REQUEST
           add length of MINUS-123-SL to ZERO giving SIMODUMP-LENGTH
           move SPACES to SIMODUMP-BUFFER
           move MINUS-123-SL-X to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
           exit.

      *****************************************************************
      * Show the Hex format for a SIGN, TRAILING, NUMERIC field...
      *****************************************************************
       EXAMPLE-06.
      *    Prepare to show the Positive Number...
           move 'Task0006' to SIMODUMP-DUMP-ID
           perform DUMP-ASTERISK-ROW-2X
           move 'PLUS-123-ST PIC S9(5) SIGN TRAILING'
             to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Show the hexadecimal content of the Positive Number...
           move 'DUMP' to SIMODUMP-REQUEST
           add  length of PLUS-123-ST to ZERO giving SIMODUMP-LENGTH
           move SPACES to SIMODUMP-BUFFER
           move PLUS-123-ST-X to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Prepare to show the Negative Number...
           perform DUMP-ASTERISK-SINGLE
           move 'MINUS-123-ST PIC S9(5) SIGN TRAILING'
             to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Show the hexadecimal content of the Negative Number...
           move 'DUMP' to SIMODUMP-REQUEST
           add length of MINUS-123-ST to ZERO giving SIMODUMP-LENGTH
           move SPACES to SIMODUMP-BUFFER
           move MINUS-123-ST-X to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
           exit.

      *****************************************************************
      * Show Hex format for a SIGN, LEADING, SEPARATE, NUMERIC field...
      *****************************************************************
       EXAMPLE-07.
      *    Prepare to show the Positive Number...
           move 'Task0007' to SIMODUMP-DUMP-ID
           perform DUMP-ASTERISK-ROW-2X
           move 'PLUS-123-SLS PIC S9(5) SIGN LEADING SEPARATE'
             to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Show the hexadecimal content of the Positive Number...
           move 'DUMP' to SIMODUMP-REQUEST
           add  length of PLUS-123-SLS to ZERO giving SIMODUMP-LENGTH
           move SPACES to SIMODUMP-BUFFER
           move PLUS-123-SLS-X to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Prepare to show the Negative Number...
           perform DUMP-ASTERISK-SINGLE
           move 'MINUS-123-SLS PIC S9(5) SIGN LEADING SEPARATE'
             to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Show the hexadecimal content of the Negative Number...
           move 'DUMP' to SIMODUMP-REQUEST
           add  length of MINUS-123-SLS to ZERO giving SIMODUMP-LENGTH
           move SPACES to SIMODUMP-BUFFER
           move MINUS-123-SLS-X to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
           exit.

      *****************************************************************
      * Show Hex format for a SIGN, TRAILING, SEPARATE, NUMERIC field.
      *****************************************************************
       EXAMPLE-08.
      *    Prepare to show the Positive Number...
           move 'Task0008' to SIMODUMP-DUMP-ID
           perform DUMP-ASTERISK-ROW-2X
           move 'PLUS-123-STS PIC S9(5) SIGN TRAILING SEPARATE'
             to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Show the hexadecimal content of the Positive Number...
           move 'DUMP' to SIMODUMP-REQUEST
           add length of PLUS-123-STS to ZERO giving SIMODUMP-LENGTH
           move SPACES to SIMODUMP-BUFFER
           move PLUS-123-STS-X to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Prepare to show the Negative Number...
           perform DUMP-ASTERISK-SINGLE
           move 'MINUS-123-STS PIC S9(5) SIGN TRAILING SEPARATE'
             to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
      *    Show the hexadecimal content of the Negative Number...
           move 'DUMP' to SIMODUMP-REQUEST
           add length of MINUS-123-STS to ZERO giving SIMODUMP-LENGTH
           move SPACES to SIMODUMP-BUFFER
           move MINUS-123-STS-X to SIMODUMP-BUFFER
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
           exit.

      *****************************************************************
      * Show the Specfied size and actual field length.
      *****************************************************************
       EXAMPLE-09.
           move 'Task0009' to SIMODUMP-DUMP-ID
           perform DUMP-ASTERISK-ROW-2X
      *
           add length of NBR-01-DIGITS to ZERO giving DIGITS-LENGTH
           add length of NBR-01-PACKED to ZERO giving PACKED-LENGTH
           add length of NBR-01-BINARY to ZERO giving BINARY-LENGTH
           move 'NBR-01 Field Sizes for PIC 9' to FIELD-NAME
           move LENGTH-OF-FIELDS to SIMODUMP-BUFFER
           perform Z-POST-NOTE-AND-CLEAR
      *
           add length of NBR-02-DIGITS to ZERO giving DIGITS-LENGTH
           add length of NBR-02-PACKED to ZERO giving PACKED-LENGTH
           add length of NBR-02-BINARY to ZERO giving BINARY-LENGTH
           move 'NBR-02 Field Sizes for PIC 99' to FIELD-NAME
           move LENGTH-OF-FIELDS to SIMODUMP-BUFFER
           perform Z-POST-NOTE-AND-CLEAR
      *
           add length of NBR-03-DIGITS to ZERO giving DIGITS-LENGTH
           add length of NBR-03-PACKED to ZERO giving PACKED-LENGTH
           add length of NBR-03-BINARY to ZERO giving BINARY-LENGTH
           move 'NBR-03 Field Sizes for PIC 999' to FIELD-NAME
           move LENGTH-OF-FIELDS to SIMODUMP-BUFFER
           perform Z-POST-NOTE-AND-CLEAR
      *
           add length of NBR-04-DIGITS to ZERO giving DIGITS-LENGTH
           add length of NBR-04-PACKED to ZERO giving PACKED-LENGTH
           add length of NBR-04-BINARY to ZERO giving BINARY-LENGTH
           move 'NBR-04 Field Sizes for PIC 9(4)' to FIELD-NAME
           move LENGTH-OF-FIELDS to SIMODUMP-BUFFER
           perform Z-POST-NOTE-AND-CLEAR
      *
           add length of NBR-05-DIGITS to ZERO giving DIGITS-LENGTH
           add length of NBR-05-PACKED to ZERO giving PACKED-LENGTH
           add length of NBR-05-BINARY to ZERO giving BINARY-LENGTH
           move 'NBR-05 Field Sizes for PIC 9(5)' to FIELD-NAME
           move LENGTH-OF-FIELDS to SIMODUMP-BUFFER
           perform Z-POST-NOTE-AND-CLEAR
      *
           add length of NBR-06-DIGITS to ZERO giving DIGITS-LENGTH
           add length of NBR-06-PACKED to ZERO giving PACKED-LENGTH
           add length of NBR-06-BINARY to ZERO giving BINARY-LENGTH
           move 'NBR-06 Field Sizes for PIC 9(6)' to FIELD-NAME
           move LENGTH-OF-FIELDS to SIMODUMP-BUFFER
           perform Z-POST-NOTE-AND-CLEAR
      *
           add length of NBR-07-DIGITS to ZERO giving DIGITS-LENGTH
           add length of NBR-07-PACKED to ZERO giving PACKED-LENGTH
           add length of NBR-07-BINARY to ZERO giving BINARY-LENGTH
           move 'NBR-07 Field Sizes for PIC 9(7)' to FIELD-NAME
           move LENGTH-OF-FIELDS to SIMODUMP-BUFFER
           perform Z-POST-NOTE-AND-CLEAR
      *
           add length of NBR-08-DIGITS to ZERO giving DIGITS-LENGTH
           add length of NBR-08-PACKED to ZERO giving PACKED-LENGTH
           add length of NBR-08-BINARY to ZERO giving BINARY-LENGTH
           move 'NBR-08 Field Sizes for PIC 9(8)' to FIELD-NAME
           move LENGTH-OF-FIELDS to SIMODUMP-BUFFER
           perform Z-POST-NOTE-AND-CLEAR
      *
           add length of NBR-09-DIGITS to ZERO giving DIGITS-LENGTH
           add length of NBR-09-PACKED to ZERO giving PACKED-LENGTH
           add length of NBR-09-BINARY to ZERO giving BINARY-LENGTH
           move 'NBR-09 Field Sizes for PIC 9(9)' to FIELD-NAME
           move LENGTH-OF-FIELDS to SIMODUMP-BUFFER
           perform Z-POST-NOTE-AND-CLEAR
      *
           add length of NBR-10-DIGITS to ZERO giving DIGITS-LENGTH
           add length of NBR-10-PACKED to ZERO giving PACKED-LENGTH
           add length of NBR-10-BINARY to ZERO giving BINARY-LENGTH
           move 'NBR-10 Field Sizes for PIC 9(10)' to FIELD-NAME
           move LENGTH-OF-FIELDS to SIMODUMP-BUFFER
           perform Z-POST-NOTE-AND-CLEAR
      *
           add length of NBR-11-DIGITS to ZERO giving DIGITS-LENGTH
           add length of NBR-11-PACKED to ZERO giving PACKED-LENGTH
           add length of NBR-11-BINARY to ZERO giving BINARY-LENGTH
           move 'NBR-11 Field Sizes for PIC 9(11)' to FIELD-NAME
           move LENGTH-OF-FIELDS to SIMODUMP-BUFFER
           perform Z-POST-NOTE-AND-CLEAR
      *
           add length of NBR-12-DIGITS to ZERO giving DIGITS-LENGTH
           add length of NBR-12-PACKED to ZERO giving PACKED-LENGTH
           add length of NBR-12-BINARY to ZERO giving BINARY-LENGTH
           move 'NBR-12 Field Sizes for PIC 9(12)' to FIELD-NAME
           move LENGTH-OF-FIELDS to SIMODUMP-BUFFER
           perform Z-POST-NOTE-AND-CLEAR
      *
           add length of NBR-13-DIGITS to ZERO giving DIGITS-LENGTH
           add length of NBR-13-PACKED to ZERO giving PACKED-LENGTH
           add length of NBR-13-BINARY to ZERO giving BINARY-LENGTH
           move 'NBR-13 Field Sizes for PIC 9(13)' to FIELD-NAME
           move LENGTH-OF-FIELDS to SIMODUMP-BUFFER
           perform Z-POST-NOTE-AND-CLEAR
      *
           add length of NBR-14-DIGITS to ZERO giving DIGITS-LENGTH
           add length of NBR-14-PACKED to ZERO giving PACKED-LENGTH
           add length of NBR-14-BINARY to ZERO giving BINARY-LENGTH
           move 'NBR-14 Field Sizes for PIC 9(14)' to FIELD-NAME
           move LENGTH-OF-FIELDS to SIMODUMP-BUFFER
           perform Z-POST-NOTE-AND-CLEAR
      *
           add length of NBR-15-DIGITS to ZERO giving DIGITS-LENGTH
           add length of NBR-15-PACKED to ZERO giving PACKED-LENGTH
           add length of NBR-15-BINARY to ZERO giving BINARY-LENGTH
           move 'NBR-15 Field Sizes for PIC 9(15)' to FIELD-NAME
           move LENGTH-OF-FIELDS to SIMODUMP-BUFFER
           perform Z-POST-NOTE-AND-CLEAR
      *
           add length of NBR-16-DIGITS to ZERO giving DIGITS-LENGTH
           add length of NBR-16-PACKED to ZERO giving PACKED-LENGTH
           add length of NBR-16-BINARY to ZERO giving BINARY-LENGTH
           move 'NBR-16 Field Sizes for PIC 9(16)' to FIELD-NAME
           move LENGTH-OF-FIELDS to SIMODUMP-BUFFER
           perform Z-POST-NOTE-AND-CLEAR
      *
           add length of NBR-17-DIGITS to ZERO giving DIGITS-LENGTH
           add length of NBR-17-PACKED to ZERO giving PACKED-LENGTH
           add length of NBR-17-BINARY to ZERO giving BINARY-LENGTH
           move 'NBR-17 Field Sizes for PIC 9(17)' to FIELD-NAME
           move LENGTH-OF-FIELDS to SIMODUMP-BUFFER
           perform Z-POST-NOTE-AND-CLEAR
      *
           add length of NBR-18-DIGITS to ZERO giving DIGITS-LENGTH
           add length of NBR-18-PACKED to ZERO giving PACKED-LENGTH
           add length of NBR-18-BINARY to ZERO giving BINARY-LENGTH
           move 'NBR-18 Field Sizes for PIC 9(18)' to FIELD-NAME
           move LENGTH-OF-FIELDS to SIMODUMP-BUFFER
           perform Z-POST-NOTE-AND-CLEAR
      *
           perform DUMP-ASTERISK-ROW
      *
           exit.

      *****************************************************************
       FIRST-TIME-LOGIC.
           perform Z-POST-COPYRIGHT.
           move 'DUMP' to SIMODUMP-REQUEST
           move 'OUT2' to SIMODUMP-OUTPUT
           move 'HIDE' to SIMODUMP-COPYRIGHT
           exit.

      *****************************************************************
      * The following Z-Routines perform administrative tasks         *
      * for this program.                                             *
      *****************************************************************
       Z-POST-CONSOLE-MESSAGE.
           display MESSAGE-BUFFER upon console
           move SPACES to MESSAGE-TEXT
           exit.

      *****************************************************************
       Z-POST-COPYRIGHT.
           display SIM-TITLE     upon console
           display SIM-COPYRIGHT upon console
           exit.

      *****************************************************************
       Z-POST-NOTE-AND-CLEAR.
           move 'NOTE' to SIMODUMP-REQUEST
           call 'SIMODUMP' using SIMODUMP-PASS-AREA SIMODUMP-BUFFER
           move SPACES to SIMODUMP-BUFFER
           exit.

      *****************************************************************
       Z-THANK-YOU.
           display SIM-THANKS-01 upon console
           display SIM-THANKS-02 upon console
           exit.
      *****************************************************************
      *      This example is provided by SimoTime Technologies        *
      *        Our e-mail address is: helpdesk@simotime.com           *
      *     Also, visit our Web Site at http://www.simotime.com       *
      *****************************************************************
